@@ -19,7 +19,7 @@ class TimeLabelsZone;
 class Prefs;
 using PrefsPtr = QSharedPointer<Prefs>;
 
-class TimeLabels : public QFrame
+class TimeLabels : public QWidget
 {
     Q_OBJECT
 public:
@@ -40,17 +40,17 @@ public:
     void contextMenuEvent(QContextMenuEvent *event) override;
 
     /** Returns the time zone of this label */
-    Q_REQUIRED_RESULT QTimeZone timeZone() const;
+    [[nodiscard]] QTimeZone timeZone() const;
 
     /**
       Return string which can be used as a header for the time label.
     */
-    Q_REQUIRED_RESULT QString header() const;
+    [[nodiscard]] QString header() const;
 
     /**
       Return string which can be used as a tool tip for the header.
     */
-    Q_REQUIRED_RESULT QString headerToolTip() const;
+    [[nodiscard]] QString headerToolTip() const;
 
     QSize sizeHint() const override;
 
@@ -60,9 +60,9 @@ public:
     bool event(QEvent *event) override;
 
 private:
-    Q_REQUIRED_RESULT int yposToCell(const int ypos) const;
-    Q_REQUIRED_RESULT int cellToHour(const int cell) const;
-    Q_REQUIRED_RESULT QString cellToSuffix(const int cell) const;
+    [[nodiscard]] int yposToCell(const int ypos) const;
+    [[nodiscard]] int cellToHour(const int cell) const;
+    [[nodiscard]] QString cellToSuffix(const int cell) const;
 
     /** update the position of the marker showing the mouse position */
     void mousePosChanged(QPoint pos);
@@ -72,7 +72,7 @@ private:
 
     void setCellHeight(double height);
     void colorMousePos();
-    QTimeZone mTimezone;
+    const QTimeZone mTimezone;
     int mRows;
     double mCellHeight;
     int mMiniWidth;
@@ -82,4 +82,3 @@ private:
     QFrame *mMousePos = nullptr; // shows a marker for the current mouse position in y direction
 };
 }
-
