@@ -22,7 +22,7 @@ TimeLabelsZone::TimeLabelsZone(QWidget *parent, const PrefsPtr &preferences, Age
     , mParent(qobject_cast<AgendaView *>(parent))
 {
     mTimeLabelsLayout = new QHBoxLayout(this);
-    mTimeLabelsLayout->setContentsMargins(0, 0, 0, 0);
+    mTimeLabelsLayout->setContentsMargins({});
     mTimeLabelsLayout->setSpacing(0);
 
     init();
