@@ -32,12 +32,12 @@ class EVENTVIEWS_EXPORT ListView : public EventView
 {
     Q_OBJECT
 public:
-    explicit ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent = nullptr, bool nonInteractive = false);
+    explicit ListView(QWidget *parent = nullptr, bool nonInteractive = false);
     ~ListView() override;
 
-    Q_REQUIRED_RESULT int currentDateCount() const override;
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override;
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() const override;
+    [[nodiscard]] int currentDateCount() const override;
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() const override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() const override;
 
     // Shows all incidences of the calendar
     void showAll();
@@ -87,7 +87,7 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void showNewEventPopupSignal();
-    void showIncidencePopupSignal(const Akonadi::Item &, const QDate &);
+    void showIncidencePopupSignal(const Akonadi::CollectionCalendar::Ptr &, const Akonadi::Item &, const QDate &);
 
 protected Q_SLOTS:
     void processSelectionChange();
