@@ -8,9 +8,9 @@
 
 #include "timelineitem.h"
 
-#include <KGantt/KGanttGlobal>
+#include <Akonadi/CalendarUtils>
 
-#include <CalendarSupport/Utils>
+#include <KGanttGlobal>
 
 #include <KCalUtils/IncidenceFormatter>
 
@@ -18,7 +18,7 @@ using namespace KCalendarCore;
 using namespace KCalUtils;
 using namespace EventViews;
 
-TimelineItem::TimelineItem(const Akonadi::ETMCalendar::Ptr &calendar, uint index, QStandardItemModel *model, QObject *parent)
+TimelineItem::TimelineItem(const Akonadi::CollectionCalendar::Ptr &calendar, uint index, QStandardItemModel *model, QObject *parent)
     : QObject(parent)
     , mCalendar(calendar)
     , mModel(model)
@@ -30,9 +30,14 @@ TimelineItem::TimelineItem(const Akonadi::ETMCalendar::Ptr &calendar, uint index
     mModel->insertRow(mIndex, dummyItem);
 }
 
+TimelineItem::~TimelineItem()
+{
+    mModel->removeRow(mIndex);
+}
+
 void TimelineItem::insertIncidence(const Akonadi::Item &aitem, const QDateTime &_start, const QDateTime &_end)
 {
-    const Incidence::Ptr incidence = CalendarSupport::incidence(aitem);
+    const Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(aitem);
     QDateTime start(_start);
     QDateTime end(_end);
     if (!start.isValid()) {
@@ -53,7 +58,7 @@ void TimelineItem::insertIncidence(const Akonadi::Item &aitem, const QDateTime &
         }
     }
 
-    auto item = new TimelineSubItem(mCalendar, aitem, this);
+    auto item = new TimelineSubItem(aitem, this);
 
     item->setStartTime(start);
     item->setOriginalStart(start);
@@ -94,15 +99,19 @@ void TimelineItem::setColor(const QColor &color)
     mColor = color;
 }
 
-TimelineSubItem::TimelineSubItem(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &incidence, TimelineItem *parent)
+Akonadi::CollectionCalendar::Ptr TimelineItem::calendar() const
+{
+    return mCalendar;
+}
+
+TimelineSubItem::TimelineSubItem(const Akonadi::Item &incidence, TimelineItem *parent)
     : QStandardItem()
-    , mCalendar(calendar)
     , mIncidence(incidence)
     , mParent(parent)
     , mToolTipNeedsUpdate(true)
 {
     setData(KGantt::TypeTask, KGantt::ItemTypeRole);
-    if (!CalendarSupport::incidence(incidence)->isReadOnly()) {
+    if (!Akonadi::CalendarUtils::incidence(incidence)->isReadOnly()) {
         setFlags(Qt::ItemIsSelectable);
     }
 }
@@ -137,9 +146,8 @@ void TimelineSubItem::updateToolTip()
 
     mToolTipNeedsUpdate = false;
 
-    setData(IncidenceFormatter::toolTipStr(CalendarSupport::displayName(mCalendar.data(), mIncidence.parentCollection()),
-                                           CalendarSupport::incidence(mIncidence),
-                                           originalStart().date(),
-                                           true),
-            Qt::ToolTipRole);
+    const auto name = Akonadi::CalendarUtils::displayName(mParent->calendar()->model(), mIncidence.parentCollection());
+    setData(IncidenceFormatter::toolTipStr(name, Akonadi::CalendarUtils::incidence(mIncidence), originalStart().date(), true), Qt::ToolTipRole);
 }
+
+#include "moc_timelineitem.cpp"
