@@ -9,12 +9,11 @@
 #include "timelineview_p.h"
 #include "timelineitem.h"
 
-#include <KGantt/KGanttGraphicsView>
+#include <KGanttGraphicsView>
 
-#include <Akonadi/ETMCalendar>
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/CollectionSelection>
-#include <CalendarSupport/Utils>
 #include <KCalendarCore/OccurrenceIterator>
 
 #include "calendarview_debug.h"
@@ -56,7 +55,9 @@ void TimelineViewPrivate::contextMenuRequested(QPoint point)
         Q_EMIT q->showNewEventPopupSignal();
         mSelectedItemList = Akonadi::Item::List();
     } else {
-        Q_EMIT q->showIncidencePopupSignal(tlitem->incidence(), CalendarSupport::incidence(tlitem->incidence())->dtStart().date());
+        if (const auto calendar = tlitem->parent()->calendar(); calendar) {
+            Q_EMIT q->showIncidencePopupSignal(calendar, tlitem->incidence(), Akonadi::CalendarUtils::incidence(tlitem->incidence())->dtStart().date());
+        }
 
         mSelectedItemList << tlitem->incidence();
     }
@@ -69,21 +70,19 @@ void TimelineViewPrivate::newEventWithHint(const QDateTime &dt)
     Q_EMIT q->newEventSignal(dt);
 }
 
-TimelineItem *TimelineViewPrivate::calendarItemForIncidence(const Akonadi::Item &incidence)
+TimelineItem *TimelineViewPrivate::calendarItemForIncidence(const Akonadi::Item &incidence) const
 {
-    Akonadi::ETMCalendar::Ptr calres = q->calendar();
-    TimelineItem *item = nullptr;
-    if (!calres) {
-        item = mCalendarItemMap.value(-1);
-    } else {
-        item = mCalendarItemMap.value(incidence.parentCollection().id());
+    auto item = mCalendarItemMap.constFind(incidence.parentCollection().id());
+    if (item == mCalendarItemMap.cend()) {
+        return mCalendarItemMap.value(-1);
     }
-    return item;
+
+    return *item;
 }
 
-void TimelineViewPrivate::insertIncidence(const Akonadi::Item &aitem, QDate day)
+void TimelineViewPrivate::insertIncidence(const Akonadi::CollectionCalendar::Ptr &calendar, const Akonadi::Item &aitem, QDate day)
 {
-    const Incidence::Ptr incidence = CalendarSupport::incidence(aitem);
+    const Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(aitem);
     // qCDebug(CALENDARVIEW_LOG) << "Item " << aitem.id() << " parentcollection: " << aitem.parentCollection().id();
     TimelineItem *item = calendarItemForIncidence(aitem);
     if (!item) {
@@ -92,10 +91,10 @@ void TimelineViewPrivate::insertIncidence(const Akonadi::Item &aitem, QDate day)
     }
 
     if (incidence->recurs()) {
-        KCalendarCore::OccurrenceIterator occurIter(*(q->calendar()), incidence, QDateTime(day, QTime(0, 0, 0)), QDateTime(day, QTime(23, 59, 59)));
+        KCalendarCore::OccurrenceIterator occurIter(*calendar, incidence, QDateTime(day, QTime(0, 0, 0)), QDateTime(day, QTime(23, 59, 59)));
         while (occurIter.hasNext()) {
             occurIter.next();
-            const Akonadi::Item akonadiItem = q->calendar()->item(occurIter.incidence());
+            const Akonadi::Item akonadiItem = calendar->item(occurIter.incidence());
             const QDateTime startOfOccurrence = occurIter.occurrenceStartDate();
             const QDateTime endOfOccurrence = occurIter.incidence()->endDateForStart(startOfOccurrence);
             item->insertIncidence(akonadiItem, startOfOccurrence.toLocalTime(), endOfOccurrence.toLocalTime());
@@ -107,26 +106,25 @@ void TimelineViewPrivate::insertIncidence(const Akonadi::Item &aitem, QDate day)
     }
 }
 
-void TimelineViewPrivate::insertIncidence(const Akonadi::Item &incidence)
+void TimelineViewPrivate::insertIncidence(const Akonadi::CollectionCalendar::Ptr &calendar, const Akonadi::Item &incidence)
 {
-    const Event::Ptr event = CalendarSupport::event(incidence);
+    const Event::Ptr event = Akonadi::CalendarUtils::event(incidence);
     if (!event) {
         return;
     }
 
     if (event->recurs()) {
-        insertIncidence(incidence, QDate());
+        insertIncidence(calendar, incidence, QDate());
     }
 
     for (QDate day = mStartDate; day <= mEndDate; day = day.addDays(1)) {
-        const KCalendarCore::Event::List events =
-            q->calendar()->events(day, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
+        const auto events = calendar->events(day, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
         if (events.contains(event)) {
             // PENDING(AKONADI_PORT) check if correct. also check the original if,
             // was inside the for loop (unnecessarily)
             for (const KCalendarCore::Event::Ptr &i : events) {
-                Akonadi::Item item = q->calendar()->item(i);
-                insertIncidence(item, day);
+                Akonadi::Item item = calendar->item(i);
+                insertIncidence(calendar, item, day);
             }
         }
     }
@@ -163,7 +161,7 @@ void TimelineViewPrivate::itemChanged(QStandardItem *item)
     }
 
     const Akonadi::Item i = tlit->incidence();
-    const Incidence::Ptr inc = CalendarSupport::incidence(i);
+    const Incidence::Ptr inc = Akonadi::CalendarUtils::incidence(i);
 
     QDateTime newStart(tlit->startTime());
     if (inc->allDay()) {
@@ -188,3 +186,5 @@ void TimelineViewPrivate::itemChanged(QStandardItem *item)
     TimelineItem *parent = tlit->parent();
     parent->moveItems(i, tlit->originalStart().secsTo(newStart), duration + allDayOffset);
 }
+
+#include "moc_timelineview_p.cpp"
