@@ -13,17 +13,15 @@
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 
-static const char description[] = I18N_NOOP("A test app for embedding calendarviews");
-
 int main(int argc, char **argv)
 {
     KAboutData about(QStringLiteral("viewerapp"),
                      i18n("ViewerApp"),
                      QStringLiteral("0.1"),
-                     i18n(description),
+                     i18n("A test app for embedding calendarviews"),
                      KAboutLicense::GPL,
                      i18n("Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net"));
-    about.addAuthor(i18n("Kevin Krammer"), QString(), QStringLiteral("krake@kdab.com"));
+    about.addAuthor(i18nc("@info:credit", "Kevin Krammer"), QString(), QStringLiteral("krake@kdab.com"));
 
     QCommandLineParser parser;
     QApplication app(argc, argv);
@@ -32,7 +30,7 @@ int main(int argc, char **argv)
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[viewname]"), i18n("Optional list of view names to instantiate")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[viewname]"), i18nc("@info:shell", "Optional list of view names to instantiate")));
 
     QStringList viewNames;
     for (int i = 0; i < parser.positionalArguments().count(); ++i) {
